--Check+Init globals
if GuildMessageRemoverEnabled == nil then
    GuildMessageRemoverEnabled = true;
end

if GuildMessageRemoverGlobal == nil then
    GuildMessageRemoverGlobal = false;
end

if GuildMessageRemoverEverything == nil then
    GuildMessageRemoverEverything = false;
end

if GuildMessageRemoverOfficer == nil then
    GuildMessageRemoverOfficer = false;
end

GuildMessageRemover = {};
local _, L = ...;

-- Checks if the message is destroyable
function GuildMessageRemover:CanDestroyMessage(clubId, streamId, messageId)
    local messageInfo = C_Club.GetMessageInfo(clubId, streamId, messageId);
    if not messageInfo or messageInfo.destroyed then
        return false;
    end
    
    local privileges = C_Club.GetClubPrivileges(clubId);

    if messageInfo.author.isSelf and privileges.canDestroyOwnMessage then
        return true;
    elseif privileges.canDestroyOtherMessage and GuildMessageRemoverEverything then
        return true;
    end
    return false;
end

-- Allows for toggling on and off
function GuildMessageRemover:Enable(enabled)
    if enabled then
        GuildMessageRemover.frame:RegisterEvent("CLUB_MESSAGE_ADDED");
    else 
        GuildMessageRemover.frame:UnregisterEvent("CLUB_MESSAGE_ADDED");
    end
end

function GuildMessageRemover:WipeLastMessages(count)
    local guildClubId = C_Club.GetGuildClubId();
    local lastMessageId = C_Club.GetMessageRanges(guildClubId, "1")[1].newestMessageId;

	local lastMessages = C_Club.GetMessagesBefore(guildClubId, "1", lastMessageId, count);
    for key,message in pairs(lastMessages) do
        if not message.destroyed then
            pcall (C_Club.DestroyMessage, guildClubId, "1", message.messageId);
        end
    end
end

-- Triggers on new message in guild chat
local function GuildMessageRemoverEventHandler(self, event, ...)
    local arg1, arg2, arg3 = ...;

    if GuildMessageRemoverGlobal then
        if GuildMessageRemover:CanDestroyMessage(arg1, arg2, arg3) then
            retOK, ret1 = pcall (C_Club.DestroyMessage, arg1, arg2, arg3);
        end
    else 
        if arg1 == C_Club.GetGuildClubId() then 
            if GuildMessageRemover:CanDestroyMessage(arg1, arg2, arg3) then
                if arg2 == 2 and GuildMessageRemoverOfficer then
                    retOK, ret1 = pcall (C_Club.DestroyMessage, arg1, arg2, arg3);
                end

                if arg2 == 1 then 
                    retOK, ret1 = pcall (C_Club.DestroyMessage, arg1, arg2, arg3);
                end

            end
        end
    end
end

GuildMessageRemover.frame = CreateFrame("FRAME", "GuildMessageRemoverFrame");
GuildMessageRemover.frame:SetScript("OnEvent", GuildMessageRemoverEventHandler);
